The *check-ipv4-address.ps1* Script
===========================

This PowerShell script checks the given IPv4 address for validity.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/check-ipv4-address.ps1 [[-Address] <String>] [<CommonParameters>]

-Address <String>
    Specifies the IPv4 address to check
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-ipv4-address 192.168.11.22
✅ IPv4 192.168.11.22 is valid

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Checks an IPv4 address for validity
.DESCRIPTION
	This PowerShell script checks the given IPv4 address for validity.
.PARAMETER Address
	Specifies the IPv4 address to check
.EXAMPLE
	PS> ./check-ipv4-address 192.168.11.22
	✅ IPv4 192.168.11.22 is valid
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$Address = "")

function IsIPv4AddressValid { param([string]$IP)
	$RegEx = "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
	if ($IP -match $RegEx) {
		return $true
	} else {
		return $false
	}
}

try {
	if ($Address -eq "" ) { $Address = read-host "Enter IPv4 address to validate" }

	if (IsIPv4AddressValid $Address) {
		"✅ IPv4 $Address is valid"
		exit 0 # success
	} else {
		write-warning "Invalid IPv4 address: $Address"
		exit 1
	}
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:51)*
