The *check-xml-files.ps1* Script
===========================

This PowerShell script verifies any XML file (with suffix .xml) in the given directory tree for validity.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/check-xml-files.ps1 [[-path] <String>] [<CommonParameters>]

-path <String>
    Specifies the path to the directory tree (current working dir by default)
    
    Required?                    false
    Position?                    1
    Default value                "$PWD"
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-xml-files.ps1 C:\Windows
...
✅ Checked 3387 XML files (2462 invalid, 925 valid) within 📂C:\Windows in 116 sec

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Checks all XML files in a directory tree
.DESCRIPTION
	This PowerShell script verifies any XML file (with suffix .xml) in the given directory tree for validity.
.PARAMETER path
	Specifies the path to the directory tree (current working dir by default)
.EXAMPLE
	PS> ./check-xml-files.ps1 C:\Windows
	...
	✅ Checked 3387 XML files (2462 invalid, 925 valid) within 📂C:\Windows in 116 sec
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$path = "$PWD")

try {
	$stopWatch = [system.diagnostics.stopwatch]::startNew()
	$path = Resolve-Path "$path"
	Write-Progress "Scanning any XML file within $path..."
 	[int]$valid = [int]$invalid = 0

	Get-ChildItem -path "$path" -attributes !Directory -recurse -force | Where-Object { $_.Name -like "*.xml" } | Foreach-Object {
		& $PSScriptRoot/check-xml-file.ps1 "$($_.FullName)"
		if ($lastExitCode -eq 0) { $valid++ } else { $invalid++ }
        }
	Write-Progress -completed "Done."

	[int]$total = $valid + $invalid
        [int]$elapsed = $stopWatch.Elapsed.TotalSeconds
        "✅ Checked $total XML files ($invalid invalid, $valid valid) within 📂$path in $elapsed sec"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:52)*
