The *get-sha1.ps1* Script
===========================

This PowerShell script calculates and prints the SHA1 checksum of the given file.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/get-sha1.ps1 [[-file] <String>] [<CommonParameters>]

-file <String>
    Specifies the path to the file
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./get-sha1 C:\MyFile.txt
✅ SHA1 hash is 8105D424D350E308AED92BD9DDEB74A1B53C5D7C

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Prints the SHA1 checksum of a file
.DESCRIPTION
	This PowerShell script calculates and prints the SHA1 checksum of the given file.
.PARAMETER file
	Specifies the path to the file
.EXAMPLE
	PS> ./get-sha1 C:\MyFile.txt
	✅ SHA1 hash is 8105D424D350E308AED92BD9DDEB74A1B53C5D7C
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$file = "")

try {
	if ($file -eq "" ) { $file = Read-Host "Enter the filename" }

	$Result = get-filehash $file -algorithm SHA1

	"✅ SHA1 hash is $($Result.Hash)"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:53)*
