The *list-news.ps1* Script
===========================

This PowerShell script lists the latest news by using a RSS (Really Simple Syndication) feed.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/list-news.ps1 [[-RSS_URL] <String>] [[-maxLines] <Int32>] [[-speed] <Int32>] [<CommonParameters>]

-RSS_URL <String>
    Specifies the URL to the RSS feed (Yahoo World News by default)
    
    Required?                    false
    Position?                    1
    Default value                https://news.yahoo.com/rss/world
    Accept pipeline input?       false
    Accept wildcard characters?  false

-maxLines <Int32>
    Specifies the maximum number of lines to list (24 by default)
    
    Required?                    false
    Position?                    2
    Default value                24
    Accept pipeline input?       false
    Accept wildcard characters?  false

-speed <Int32>
    Specifies the speed to write the text (10 ms by default)
    
    Required?                    false
    Position?                    3
    Default value                10
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-news.ps1
 
   UTC   Yahoo News - Latest News & Headlines - https://www.yahoo.com/news/world
   ---   -----------------------------------------------------------------------
❇️ 09:15 Deadly Mediterranean wildfires kill more than 40
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists the latest news
.DESCRIPTION
	This PowerShell script lists the latest news by using a RSS (Really Simple Syndication) feed.
.PARAMETER RSS_URL
	Specifies the URL to the RSS feed (Yahoo World News by default)
.PARAMETER maxLines
	Specifies the maximum number of lines to list (24 by default)
.PARAMETER speed
        Specifies the speed to write the text (10 ms by default)
.EXAMPLE
	PS> ./list-news.ps1
  
	   UTC   Yahoo News - Latest News & Headlines - https://www.yahoo.com/news/world
	   ---   -----------------------------------------------------------------------
	❇️ 09:15 Deadly Mediterranean wildfires kill more than 40
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$RSS_URL = "https://news.yahoo.com/rss/world", [int]$maxLines = 24, [int]$speed = 10)

try {
	[xml]$content = (Invoke-WebRequest -URI $RSS_URL -useBasicParsing).Content

	$title = $content.rss.channel.title
	$URL = $content.rss.channel.link
	" "
	"   UTC   $title - $URL"
	"   ---   -----------------------------------------------------------------------"

	[int]$count = 1
	foreach ($item in $content.rss.channel.item) {
		$title = $item.title
		$time = $item.pubDate.Substring(11, 5)
		& "$PSScriptRoot/write-typewriter.ps1" "❇️ $time $title" $speed
		if ($count++ -eq $maxLines) { break }
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:56)*
