The *list-read-only-files.ps1* Script
===========================

This PowerShell script scans a directory tree and lists all read-only files.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/list-read-only-files.ps1 [[-path] <String>] [<CommonParameters>]

-path <String>
    Specifies the path to the directory tree (current working dir by default)
    
    Required?                    false
    Position?                    1
    Default value                "$PWD"
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-read-only-files.ps1 C:\Windows
...
✅ Found 107 read-only files within 📂C:\Windows in 50 sec

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists all read-only files in a directory tree
.DESCRIPTION
	This PowerShell script scans a directory tree and lists all read-only files.
.PARAMETER path
	Specifies the path to the directory tree (current working dir by default)
.EXAMPLE
	PS> ./list-read-only-files.ps1 C:\Windows
	...
	✅ Found 107 read-only files within 📂C:\Windows in 50 sec
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$path = "$PWD")

try {
	$stopWatch = [system.diagnostics.stopwatch]::startNew()

	$path = Resolve-Path "$path"
	Write-Progress "Scanning $path for read-only files..."
	[int]$count = 0
	Get-ChildItem "$path" -attributes ReadOnly -recurse | Foreach-Object {
		"📄$($_.FullName)"
		$count++
	}
	Write-Progress -completed " "
	[int]$elapsed = $stopWatch.Elapsed.TotalSeconds
	"✅ Found $count read-only files within 📂$path in $elapsed sec" 
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:56)*
