The *list-scsi-devices.ps1* Script
===========================

This PowerShell script lists all SCSI devices connected to the local computer.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/list-scsi-devices.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-scsi-devices.ps1



FriendlyName                 Status  InstanceId
------------                 ------  ----------
Microsoft-Controller         OK      ROOT\SPACEPORT\0000
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists SCSI devices
.DESCRIPTION
	This PowerShell script lists all SCSI devices connected to the local computer.
.EXAMPLE
	PS> ./list-scsi-devices.ps1

	FriendlyName                 Status  InstanceId
	------------                 ------  ----------
	Microsoft-Controller         OK      ROOT\SPACEPORT\0000
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	Get-PnpDevice | Where-Object {$_.Class -like "SCSI*"} | Sort-Object -property FriendlyName | Format-Table -property FriendlyName,Status,InstanceId
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:56)*
