The *list-suggestions.ps1* Script
===========================

This PowerShell script lists "Did you mean?" suggestions from Google.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/list-suggestions.ps1 [[-text] <String>] [<CommonParameters>]

-text <String>
    Specifies the word or sentence to get suggestions for.
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-suggestions.ps1 Joe
joe biden
joe cocker
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists suggestions
.DESCRIPTION
	This PowerShell script lists "Did you mean?" suggestions from Google.
.EXAMPLE
	PS> ./list-suggestions.ps1 Joe
	joe biden
	joe cocker
	...
.PARAMETER text
	Specifies the word or sentence to get suggestions for.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$text = "")

try {
	if ("$text" -eq "") { $text = read-host "Enter a word or sentence to get suggestions for" }
	$URI = [uri]::escapeuristring("suggestqueries.google.com/complete/search?client=firefox&q=$text")
	$Content = (Invoke-WebRequest -URI $URI -useBasicParsing).Content 
	($Content | ConvertFrom-Json).SyncRoot | Select-Object -Skip 1
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:56)*
