The *measure-sorting-algorithms.ps1* Script
===========================

This PowerShell script measures the speed of several sorting algorithms and prints it.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/measure-sorting-algorithms.ps1 [[-numIntegers] <Int32>] [<CommonParameters>]

-numIntegers <Int32>
    Specifies the number of integers to sort (3000 by default)
    
    Required?                    false
    Position?                    1
    Default value                3000
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./measure-sorting-algorithms.ps1
🧭 6.041 sec to sort 3000 integers by BubbleSort
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Measures the speed of sorting algorithms
.DESCRIPTION
	This PowerShell script measures the speed of several sorting algorithms and prints it.
.PARAMETER numIntegers
	Specifies the number of integers to sort (3000 by default)
.EXAMPLE
	PS> ./measure-sorting-algorithms.ps1
	🧭 6.041 sec to sort 3000 integers by BubbleSort
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([int]$numIntegers = 3000)

" "
& "$PSScriptRoot/measure-BubbleSort.ps1" $numIntegers
& "$PSScriptRoot/measure-BucketSort.ps1" $numIntegers
& "$PSScriptRoot/measure-CountingSort.ps1" $numIntegers
& "$PSScriptRoot/measure-HeapSort.ps1" $numIntegers
& "$PSScriptRoot/measure-InsertionSort.ps1" $numIntegers
& "$PSScriptRoot/measure-MergeSort.ps1" $numIntegers
& "$PSScriptRoot/measure-QuickSort.ps1" $numIntegers
& "$PSScriptRoot/measure-SelectionSort.ps1" $numIntegers
exit 0 # success
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:57)*
