The *open-URL.ps1* Script
===========================

This PowerShell script launches a new tab in the default Web browser with the given URL.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/open-URL.ps1 [[-URL] <String>] [[-text] <String>] [<CommonParameters>]

-URL <String>
    Specifies the URL
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

-text <String>
    Specifies the text to write to the console
    
    Required?                    false
    Position?                    2
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./open-URL.ps1 https://cnn.com

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Opens an URL in the default browser
.DESCRIPTION
	This PowerShell script launches a new tab in the default Web browser with the given URL.
.PARAMETER URL
	Specifies the URL
.PARAMETER text
	Specifies the text to write to the console
.EXAMPLE
	PS> ./open-URL.ps1 https://cnn.com
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$URL = "", [string]$text = "")

try {
	if ($URL -eq "") { $URL = Read-Host "Enter the URL" }

	if ($text -ne "") {
		Write-Host $text -noNewline
		Write-Host $URL -foregroundColor blue
	}
	if ($IsLinux) {
	} else {
		Start-Process $URL
	}
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0]) (script line $($_.InvocationInfo.ScriptLineNumber))"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:59)*
