The *open-dashboards.ps1* Script
===========================

This PowerShell script launches the Web browser with 20 tabs of popular dashboard websites.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/open-dashboards.ps1 [[-timeInterval] <Int32>] [<CommonParameters>]

-timeInterval <Int32>
    Specifies the time interval between each tab (110ms per default)
    
    Required?                    false
    Position?                    1
    Default value                120
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./open-dashboards.ps1
✅ Launching Web browser with 20 tabs: Toggl Track•Google Calendar•Google Mail, ...
NOTE: Execute './switch-tabs.ps1' to switch from tab to tab automatically.
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Open 20 web dashboards
.DESCRIPTION
	This PowerShell script launches the Web browser with 20 tabs of popular dashboard websites.
.PARAMETER timeInterval
	Specifies the time interval between each tab (110ms per default)
.EXAMPLE
	PS> ./open-dashboards.ps1
	✅ Launching Web browser with 20 tabs: Toggl Track•Google Calendar•Google Mail, ...
	NOTE: Execute './switch-tabs.ps1' to switch from tab to tab automatically.
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([int]$timeInterval = 120) # milliseconds

try {
	Write-Progress "Reading Data/popular-dashboards.csv..."
	$table = Import-CSV "$PSScriptRoot/../data/popular-dashboards.csv"
	Write-Progress -completed "Done."

	Write-Host "✅ Launching Web browser with 20 tabs: " -noNewline
	foreach($row in $table) {
		Write-Host "$($row.NAME)•" -noNewline
		& "$PSScriptRoot/open-default-browser.ps1" "$($row.URL)"
		Start-Sleep -milliseconds $timeInterval
	}
	Write-Host ""
	Write-Host "NOTE: Execute './switch-tabs.ps1' to switch from tab to tab automatically."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:51:58)*
