The *remove-user.ps1* Script
===========================

This PowerShell script removes an existing user account including the home directory.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/remove-user.ps1 [[-username] <String>] [<CommonParameters>]

-username <String>
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./remove-user.ps1 Joe
✅ Removed user 'Joe' including home directory in 11s.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Removes an user account
.DESCRIPTION
	This PowerShell script removes an existing user account including the home directory.
.EXAMPLE
	PS> ./remove-user.ps1 Joe
	✅ Removed user 'Joe' including home directory in 11s.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$username = "")

try {
	if ($username -eq "") { $username = Read-Host "Enter the user name to remove" }
	$stopWatch = [system.diagnostics.stopwatch]::startNew()

	if ($IsLinux) {
		&  sudo deluser --remove-home $username
	} else {
		throw "Not supported yet"
	}

	[int]$elapsed = $stopWatch.Elapsed.TotalSeconds
	"✅ Removed user '$username' including home directory in $($elapsed)s."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:52:00)*
