The *speak-thai.ps1* Script
===========================

This PowerShell script speaks the given text with a Thai text-to-speech (TTS) voice.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/speak-thai.ps1 [[-text] <String>] [<CommonParameters>]

-text <String>
    Specifies the Thai text to speak
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./speak-thai.ps1 "สวัสดี"

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Speaks text in Thai
.DESCRIPTION
	This PowerShell script speaks the given text with a Thai text-to-speech (TTS) voice.
.PARAMETER text
	Specifies the Thai text to speak
.EXAMPLE
	PS> ./speak-thai.ps1 "สวัสดี"
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$text = "")

try {
	if ($text -eq "") { $text = Read-Host "Enter the Thai text to speak" }

	$TTS = New-Object -ComObject SAPI.SPVoice
	foreach ($voice in $TTS.GetVoices()) {
		if ($voice.GetDescription() -like "*- Thai*") {
			$TTS.Voice = $voice
			[void]$TTS.Speak($text)
			exit 0 # success
		}
	}
	throw "No Thai text-to-speech voice found - please install one."
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:52:01)*
