## The *start-calibre-server.ps1* Script

This PowerShell script starts a local Calibre server as background process (using Web port 8099 by default).

## Parameters
```powershell
start-calibre-server.ps1 [[-Port] <Int32>] [[-UserDB] <String>] [[-Logfile] <String>] [<CommonParameters>]

-Port <Int32>
    Specifies the Web port number (8099 by default)
    
    Required?                    false
    Position?                    1
    Default value                8099
    Accept pipeline input?       false
    Accept wildcard characters?  false

-UserDB <String>
    
    Required?                    false
    Position?                    2
    Default value                "$HOME/CalibreUsers.sqlite"
    Accept pipeline input?       false
    Accept wildcard characters?  false

-Logfile <String>
    
    Required?                    false
    Position?                    3
    Default value                "$HOME/CalibreServer.log"
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

## Example
```powershell
PS> ./start-calibre-server

```

## Notes
Author: Markus Fleschutz | License: CC0

## Related Links
https://github.com/fleschutz/PowerShell

## Source Code
```powershell
<#
.SYNOPSIS
	Starts a Calibre server
.DESCRIPTION
	This PowerShell script starts a local Calibre server as background process (using Web port 8099 by default).
.PARAMETER port
	Specifies the Web port number (8099 by default)
.EXAMPLE
	PS> ./start-calibre-server
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([int]$Port = 8099, [string]$UserDB = "$HOME/CalibreUsers.sqlite", [string]$Logfile = "$HOME/CalibreServer.log")

try {
	$StopWatch = [system.diagnostics.stopwatch]::startNew()

	"⏳ Step 1/2 - Searching for Calibre server executable..."
	& calibre-server --version
	if ($lastExitCode -ne "0") { throw "Can't execute 'calibre-server' - make sure Calibre server is installed and available" }

	"⏳ Step 2/2 - Starting Calibre server as background process..."
	"   (Web port $Port, user DB at $UserDB, log file at $Logfile)"
	& calibre-server --port $Port --num-per-page 100 --userdb $UserDB --log $Logfile --daemonize $HOME/'Calibre Library'

	[int]$Elapsed = $StopWatch.Elapsed.TotalSeconds
	"✔️ started Calibre server in $Elapsed sec"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*Generated by convert-ps2md.ps1 using the comment-based help of start-calibre-server.ps1*
