The *switch-shelly1.ps1* Script
===========================

This PowerShell script switches a Shelly1 device in the local network.

Parameters
----------
```powershell
/home/markus/Repos/PowerShell/scripts/switch-shelly1.ps1 [[-host] <String>] [[-turnMode] <String>] [[-timer] <Int32>] [<CommonParameters>]

-host <String>
    Specifies either the hostname or IP address of the Shelly1 device
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

-turnMode <String>
    Specifies either 'on', 'off', or 'toggle'
    
    Required?                    false
    Position?                    2
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

-timer <Int32>
    Specifies the timer in seconds (0 = infinite)
    
    Required?                    false
    Position?                    3
    Default value                -999
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./switch-shelly1 192.168.100.100 toggle 10

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Switches a Shelly1 device 
.DESCRIPTION
	This PowerShell script switches a Shelly1 device in the local network.
.PARAMETER host
	Specifies either the hostname or IP address of the Shelly1 device
.PARAMETER turnMode
	Specifies either 'on', 'off', or 'toggle'
.PARAMETER timer
	Specifies the timer in seconds (0 = infinite)
.EXAMPLE
	PS> ./switch-shelly1 192.168.100.100 toggle 10
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$host = "", [string]$turnMode = "", [int]$timer = -999)

try {
	if ($host -eq "") { $host = Read-Host "Enter the hostname or IP address of the Shelly1 device" }
	if ($turnMode -eq "") { $turnMode = Read-Host "Enter the turn mode (on/off/toggle)" }
	if ($timer -eq -999) { [int]$timer = Read-Host "Enter the timer in seconds (0=endless)" }

	$result = Invoke-RestMethod "http://$($host)/relay/0?turn=$($turnMode)&timer=$($timer)"
	
	"✅ Switched Shelly1 device at $host to $turnMode for $timer sec."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:52:01)*
