Script: *uninstall-github-cli.ps1*
========================

This PowerShell script uninstalls the GitHub CLI from the local computer.

Parameters
----------
```powershell
PS> ./uninstall-github-cli.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./uninstall-github-cli.ps1
⏳ Uninstalling GitHub CLI...
✔️ Removal of GitHub CLI took 7 sec

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Uninstalls GitHub CLI
.DESCRIPTION
	This PowerShell script uninstalls the GitHub CLI from the local computer.
.EXAMPLE
	PS> ./uninstall-github-cli.ps1
	⏳ Uninstalling GitHub CLI...
	✔️ Removal of GitHub CLI took 7 sec
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	"⏳ Uninstalling GitHub CLI..."
	$StopWatch = [system.diagnostics.stopwatch]::startNew()

	if ($IsMacOS) {
		& brew uninstall gh
	} elseif ($IsLinux) {
		& sudo apt remote gh
	} else {
		& winget uninstall --id GitHub.cli
	}
	if ($lastExitCode -ne "0") { throw "Can't uninstall GitHub CLI, is it installed?" }

	[int]$Elapsed = $StopWatch.Elapsed.TotalSeconds
	"✔️ Removal of GitHub CLI took $Elapsed sec"
	exit 0 # success
} catch {
	"Sorry: $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of uninstall-github-cli.ps1 as of 08/15/2024 09:50:55)*
