The *write-fractal.ps1* Script
===========================

write-fractal.ps1 


Parameters
----------
```powershell


[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Script Content
--------------
```powershell
<#
.SYNOPSIS
        Writes a fractal
.DESCRIPTION
        This PowerShell script writes an animated Mandelbrot fractal.
.EXAMPLE
        PS> ./write-fractal.ps1
.LINK
        https://github.com/fleschutz/PowerShell
.NOTES
        Author: Markus Fleschutz | License: CC0
#>

function CalculateFractal([float]$left, [float]$top, [float]$xside, [float]$yside, [float]$zoom) { 
	[int]$maxx = $rui.MaxWindowSize.Width
	[int]$maxy = $rui.MaxWindowSize.Height
	[float]$xscale = $xside / $maxx 
	[float]$yscale = $yside / $maxy 
	for ([int]$y = 0; $y -lt $maxy; $y++) { 
		for ([int]$x = 0; $x -lt $maxx; $x++) { 
			[float]$cx = $x * $xscale + $left
			[float]$cy = $y * $yscale + $top
			[float]$zx = 0
			[float]$zy = 0
			for ([int]$count = 0; ($zx * $zx + $zy * $zy -lt 4) -and ($count -lt $MAXCOUNT); $count++) { 
				[float]$tempx = $zx * $zx - $zy * $zy + $cx
				$zy = $zoom * $zx * $zy + $cy
				$zx = $tempx
			} 
			$global:buf[$y * $maxx + $x] = $([char](65 + $count))
		} 
	}
}

$MAXCOUNT = 30 
$ui = (Get-Host).ui
$rui = $ui.rawui
[float]$left = -1.75 
[float]$top = -0.25 
[float]$xside = 0.25 
[float]$yside = 0.45 
$buffer0 = ""
1..($rui.MaxWindowSize.Width * $rui.MaxWindowSize.Height) | ForEach-Object { $buffer0 += " " }
$global:buf = $buffer0.ToCharArray()

while ($true) {
	for ([float]$zoom = 4.0; $zoom -gt 1.1; $zoom -= 0.02) {
		CalculateFractal $left $top $xside $yside $zoom
		[console]::SetCursorPosition(0,0)
		[string]$Screen = New-Object system.string($global:buf, 0, $global:buf.Length)
		Write-Host -foreground green $Screen -noNewline
	}
	for ([float]$zoom = 1.1; $zoom -lt 4.0; $zoom += 0.02) {
		CalculateFractal $left $top $xside $yside $zoom
		[console]::SetCursorPosition(0,0)
		[string]$Screen = New-Object system.string($global:buf, 0, $global:buf.Length)
		Write-Host -foreground green $Screen -noNewline
	}
}
exit 0 # success
```

*(generated by convert-ps2md.ps1 as of 11/20/2024 11:52:02)*
